==> zurmo-1.0.20p1.tgz: zurmo/app/protected/modules/conversations/views/ConversationsZeroModelsYetView.php <==
<?php
    /*********************************************************************************
     * Zurmo is a customer relationship management program developed by
     * Zurmo, Inc. Copyright (C) 2012 Zurmo Inc.
     *
     * Zurmo is free software; you can redistribute it and/or modify it under
     * the terms of the GNU General Public License version 3 as published by the
     * Free Software Foundation with the addition of the following permission added
     * to Section 15 as permitted in Section 7(a): FOR ANY PART OF THE COVERED WORK
     * IN WHICH THE COPYRIGHT IS OWNED BY ZURMO, ZURMO DISCLAIMS THE WARRANTY
     * OF NON INFRINGEMENT OF THIRD PARTY RIGHTS.
     *
     * Zurmo is distributed in the hope that it will be useful, but WITHOUT
     * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
     * FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
     * details.
     *
     * You should have received a copy of the GNU General Public License along with
     * this program; if not, see http://www.gnu.org/licenses or write to the Free
     * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
     * 02110-1301 USA.
     *
     * You can contact Zurmo, Inc. with a mailing address at 113 McHenry Road Suite 207,
     * Buffalo Grove, IL 60089, USA. or at email address contact@zurmo.com.
     ********************************************************************************/

    /**
     * Class for showing a message and create link when there are no conversations visible to the logged in user when
     * going to the conversations list view.
     */
    class ConversationsZeroModelsYetView extends ZeroModelsYetView
    {
        protected function getCreateLinkDisplayLabel()
        {
            return Yii::t('Default', 'Create Conversation');
        }

        protected function getMessageContent()
        {
            return Yii::t('Default', '<h2>"A single conversation with a wise man is better than ten years of study."' .
                                     '</h2><i>- Chinese proverb</i></i><div class="large-icon"></div><p>' .
                                     'Start a conversation with someone "wise" in your organization about a record ' .
                                     'in the CRM or perhaps something unrelated.  When you are conversing within the ' .
                                     'CRM, it is better than "ten" replies in email.' .
                                     'customer we interact with."</p>');
        }
    }
?>

==> zurmo-1.1.31.tgz: zurmo/app/protected/modules/conversations/views/ConversationsZeroModelsYetView.php <==
<?php
    /*********************************************************************************
     * Zurmo is a customer relationship management program developed by
     * Zurmo, Inc. Copyright (C) 2012 Zurmo Inc.
     *
     * Zurmo is free software; you can redistribute it and/or modify it under
     * the terms of the GNU General Public License version 3 as published by the
     * Free Software Foundation with the addition of the following permission added
     * to Section 15 as permitted in Section 7(a): FOR ANY PART OF THE COVERED WORK
     * IN WHICH THE COPYRIGHT IS OWNED BY ZURMO, ZURMO DISCLAIMS THE WARRANTY
     * OF NON INFRINGEMENT OF THIRD PARTY RIGHTS.
     *
     * Zurmo is distributed in the hope that it will be useful, but WITHOUT
     * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
     * FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
     * details.
     *
     * You should have received a copy of the GNU General Public License along with
     * this program; if not, see http://www.gnu.org/licenses or write to the Free
     * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
     * 02110-1301 USA.
     *
     * You can contact Zurmo, Inc. with a mailing address at 113 McHenry Road Suite 207,
     * Buffalo Grove, IL 60089, USA. or at email address contact@zurmo.com.
     ********************************************************************************/

    /**
     * Class for showing a message and create link when there are no conversations visible to the logged in user when
     * going to the conversations list view.
     */
    class ConversationsZeroModelsYetView extends ZeroModelsYetView
    {
        protected function getCreateLinkDisplayLabel()
        {
            return Zurmo::t('ConversationsModule', 'Create Conversation');
        }

        protected function getMessageContent()
        {
            return Zurmo::t('ConversationsModule', '<h2>"A single conversation with a wise man is better than ten years of study."' .
                                     '</h2><i>- Chinese proverb</i></i><div class="large-icon"></div><p>' .
                                     'Start a conversation with someone "wise" in your organization about a record ' .
                                     'in the CRM or perhaps something unrelated.  When you are conversing within the ' .
                                     'CRM, it is better than "ten" replies in email.</p>');
        }
    }
?>
